@@ -16,14 +16,29 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
+# pylint: disable=C0413
 """Extensions over the Telegram Bot API to facilitate bot making"""
 
+from .extbot import ExtBot
 from .basepersistence import BasePersistence
 from .picklepersistence import PicklePersistence
 from .dictpersistence import DictPersistence
 from .handler import Handler
 from .callbackcontext import CallbackContext
+from .contexttypes import ContextTypes
 from .dispatcher import Dispatcher, DispatcherHandlerStop, run_async
+
+# https://bugs.python.org/issue41451, fixed on 3.7+, doesn't actually remove slots
+# try-except is just  here in case the __init__ is called twice (like in the tests)
+# this block is also the reason for the pylint-ignore at the top of the file
+try:
+    del Dispatcher.__slots__
+except AttributeError as exc:
+    if str(exc) == '__slots__':
+        pass
+    else:
+        raise exc
+
 from .jobqueue import JobQueue, Job
 from .updater import Updater
 from .callbackqueryhandler import CallbackQueryHandler
@@ -45,40 +60,45 @@ from .pollanswerhandler import PollAnswerHandler
 from .pollhandler import PollHandler
 from .chatmemberhandler import ChatMemberHandler
 from .defaults import Defaults
+from .callbackdatacache import CallbackDataCache, InvalidCallbackData
 
 __all__ = (
-    'Dispatcher',
-    'JobQueue',
-    'Job',
-    'Updater',
+    'BaseFilter',
+    'BasePersistence',
+    'CallbackContext',
+    'CallbackDataCache',
     'CallbackQueryHandler',
+    'ChatMemberHandler',
     'ChosenInlineResultHandler',
     'CommandHandler',
+    'ContextTypes',
+    'ConversationHandler',
+    'Defaults',
+    'DelayQueue',
+    'DictPersistence',
+    'Dispatcher',
+    'DispatcherHandlerStop',
+    'ExtBot',
+    'Filters',
     'Handler',
     'InlineQueryHandler',
-    'MessageHandler',
-    'BaseFilter',
+    'InvalidCallbackData',
+    'Job',
+    'JobQueue',
     'MessageFilter',
-    'UpdateFilter',
-    'Filters',
+    'MessageHandler',
+    'MessageQueue',
+    'PicklePersistence',
+    'PollAnswerHandler',
+    'PollHandler',
+    'PreCheckoutQueryHandler',
+    'PrefixHandler',
     'RegexHandler',
+    'ShippingQueryHandler',
     'StringCommandHandler',
     'StringRegexHandler',
     'TypeHandler',
-    'ConversationHandler',
-    'PreCheckoutQueryHandler',
-    'ShippingQueryHandler',
-    'MessageQueue',
-    'DelayQueue',
-    'DispatcherHandlerStop',
+    'UpdateFilter',
+    'Updater',
     'run_async',
-    'CallbackContext',
-    'BasePersistence',
-    'PicklePersistence',
-    'DictPersistence',
-    'PrefixHandler',
-    'PollAnswerHandler',
-    'PollHandler',
-    'ChatMemberHandler',
-    'Defaults',
 )
